@@ -9,7 +9,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '0.1914';
+our $VERSION = '0.1915';
 
 1;
 
@@ -25,7 +25,7 @@ Task::MusicBundle - MIDI and music creation modules
 
 =head1 VERSION
 
-version 0.1914
+version 0.1915
 
 =head1 SYNOPSIS
 
@@ -62,7 +62,7 @@ L<Guitar::Scale>
 
 L<MIDI>
 
-L<MIDI::Bassline::Walk>
+L<Music::Bassline::Generator>
 
 L<MIDI::Chord::Guitar>
 
